pub struct MultiStarkVerifyingKey<SC: StarkProtocolConfig> {
pub inner: MultiStarkVerifyingKey0<SC>,
pub pre_hash: SC::Digest,
}Expand description
Common verifying key for multiple AIRs.
This struct contains the necessary data for the verifier to verify proofs generated for multiple AIRs using a single verifying key.
Fields
inner: MultiStarkVerifyingKey0<SC>All parts of the verifying key needed by the verifier, except
the pre_hash used to initialize the Fiat-Shamir transcript.
pre_hash: SC::DigestThe hash of all other parts of the verifying key. The Fiat-Shamir hasher will initialize by observing this hash.
Implementations
Sourceimpl<SC: StarkProtocolConfig> MultiStarkVerifyingKey<SC>
impl<SC: StarkProtocolConfig> MultiStarkVerifyingKey<SC>
Sourcepub fn max_constraint_degree(&self) -> usize
pub fn max_constraint_degree(&self) -> usize
Global maximum constraint degree across all AIRs and Interactions.