#[repr(C)]pub struct StarkVerifyingKey<F, Digest> {
pub preprocessed_data: Option<VerifierSinglePreprocessedData<Digest>>,
pub params: StarkVerifyingParams,
pub symbolic_constraints: SymbolicConstraintsDag<F>,
pub max_constraint_degree: u8,
pub is_required: bool,
pub unused_variables: Vec<SymbolicVariable<F>>,
}Expand description
Verifying key for a single STARK (corresponding to single AIR matrix)
Fields
preprocessed_data: Option<VerifierSinglePreprocessedData<Digest>>Preprocessed trace data, if any
params: StarkVerifyingParamsParameters of the STARK
symbolic_constraints: SymbolicConstraintsDag<F>Symbolic constraints of the AIR in all challenge phases. This is a serialization of the constraints in the AIR.
max_constraint_degree: u8The maximum degree of any polynomial (constraint or interaction) for this AIR.
is_required: boolTrue means this AIR must have non-empty trace.
unused_variables: Vec<SymbolicVariable<F>>Symbolic variables referenced unreferenced by the AIR.
Implementations
Sourceimpl<Val, Com> StarkVerifyingKey<Val, Com>
impl<Val, Com> StarkVerifyingKey<Val, Com>
pub fn num_cached_mains(&self) -> usize
pub fn num_parts(&self) -> usize
pub fn has_interaction(&self) -> bool
pub fn num_interactions(&self) -> usize
Sourcepub fn dag_main_part_index_to_commit_index(&self, index: usize) -> usize
pub fn dag_main_part_index_to_commit_index(&self, index: usize) -> usize
Converts from a main part index (as used by the constraint DAG) to the commitment part indexing scheme that includes preprocessed trace.