#[repr(C)]pub struct StarkVerifyingParams {
pub width: TraceWidth,
pub num_public_values: usize,
pub need_rot: bool,
}Fields
width: TraceWidthTrace sub-matrix widths
num_public_values: usizeNumber of public values for this STARK only
need_rot: boolA flag indicating whether at least one rotated variable is used in any of the constraints and/or interactions across all trace parts (common, preprocessed if there is one, all cached).